@@ -11,12 +11,13 @@ import DateTime
 
 def get_dateformat(
     datestring: str,
+    checkonly: bool = False,
     leading_zeroes: bool = True,
     for_DateTime: bool = False
 ) -> str:
     """Get the format string needed to convert a datetime string to an object
 
-    :param datestring:
+    :param checkonly: if the datestring is invalid, return False instead of raising an error
     :todo: times!
     :raises ValueError: if an invalid datetime or DateTime string is provided
     """
@@ -49,12 +50,16 @@ def get_dateformat(
         try:
             DateTime.DateTime(datestring, datefmt=datefmt)
         except DateTime.interfaces.DateError:
+            if checkonly:
+                return False
             msg = datestring + ' is not a valid DateTime string.'
             raise ValueError(msg)
     else:
         try:
             datetime.datetime.strptime(datestring, datefmt)
         except ValueError:
+            if checkonly:
+                return False
             msg = datestring + ' is not a valid date or datetime string.'
             raise ValueError(msg)
 
@@ -63,6 +68,8 @@ def get_dateformat(
                 '%d', '%-d'
             ).replace('%m', '%-m')
 
+    if checkonly:
+        return True
     return datefmt
 
 
