@@ -253,10 +253,14 @@ def map_special_chars(
 ) -> str:
     """ map special characters
 
+    .. note:: Umlauts are even recognized if the do not use the appropriate characters but
+              a vowel followed by a COMBINING DIAERESIS (U+0308) character instead.
+
     :param sort: case is preserved in any case. If you want lowercase, you have to feed
                  the function appropriately.
                  If sort is set to True, all character lengths are preserved.
     """
+    text = normalize_text(text)
 
     intab = 'AAAÁÀÂÃ?aaaáàâãå?CCCCccccçDÐddEEEEEÉÈÊËeeeeeéèêëGGggÍÌÎÏíìîïÓÒÔóòôõøñÚÙÛúùûÝýÿ'
 
@@ -305,6 +309,28 @@ def map_special_chars(
     return text
 
 
+def normalize_text(
+    text
+):
+    """ normalize text
+
+    replace problematic (two-character) unicode characters
+    """
+    transDict = {
+        'ä': 'ä',  # a and unicode cc 88 (), etc...
+        'ö': 'ö',
+        'ü': 'ü',
+        'Ä': 'Ä',
+        'Ö': 'Ö',
+        'Ü': 'Ü'
+    }
+
+    for key in list(transDict.keys()):
+        text = text.replace(key, transDict[key])
+
+    return text
+
+
 def normalize_name(
     name,
     returning: str = 'str'
